#include "dock.h"

/// @brief Create dock windows on all screens
/// @param app Qt Application callback
void Dock::createDockWindows(QApplication* app) {
    for (int i = 0; i < this->m_screens.size(); ++i) {
        QScreen* screen = this->m_screens[i];

        qDebug() << "Creating dock window for screen:" << screen->name();

        QWidget* container = new QWidget(nullptr, Qt::FramelessWindowHint | Qt::Tool);
        // container->setAttribute(Qt::WA_TranslucentBackground);
        // container->setAttribute(Qt::WA_NoSystemBackground);
        container->setWindowFlag(Qt::WindowStaysOnTopHint);
        container->setObjectName("rootWindow");
        container->setAutoFillBackground(true);
        container->resize(screen->geometry().size().width() / 2, 60);
        container->setStyleSheet(R"(
            #rootWindow {
                background-color: rgba(0,0,0,0.6);
            }
        )");

        this->m_dockWindows.push_front(container);
        
        QLabel* label = new QLabel(QString("✨ Dock %1 ✨").arg(i));
        label->setAlignment(Qt::AlignCenter);
        label->setStyleSheet(R"(
            QLabel {
                color: white;
                font-size: 18px;
            }
        )");

        QPushButton* button = new QPushButton(QString("Start"));

        QHBoxLayout* layout = new QHBoxLayout(container);
        layout->addWidget(label);
        layout->addWidget(button);
        layout->setContentsMargins(0, 0, 0, 0);

        QRect screenRect = screen->geometry();
        int x = screenRect.center().x() - container->width() / 2;
        int y = screenRect.bottom() - container->height();
        container->move(x, y);

        container->show();
    }

    app->exec();
}

Dock::Dock(QApplication* app) {
    this->createDockWindows(app);
}

Dock::~Dock() {};